from django.apps import AppConfig

class DjangoAppNovadataConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'django_app_novadata'

    def ready(self):
        import django_app_novadata.signals



# Generated by Django 3.2.12 on 2022-06-14 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ConteudoCustom',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('local', models.CharField(choices=[('Nenhum Local', 'Nenhum Local'), ('Head - Admin', 'Head - Admin'), ('Style - Admin', 'Style - Admin'), ('Script - Admin', 'Script - Admin')], default='Nenhum Local', max_length=100, verbose_name='')),
                ('conteudo', models.TextField(null=True, verbose_name='Conteúdo')),
            ],
            options={
                'verbose_name': 'Conteúdo Customizado',
                'verbose_name_plural': 'Conteúdos Customizados',
            },
        ),
    ]



# Generated by Django 3.2.12 on 2022-06-28 19:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_app_novadata', '0002_conteudocustom_logo'),
    ]

    operations = [
        migrations.AlterField(
            model_name='conteudocustom',
            name='local',
            field=models.CharField(choices=[('Nenhum Local', 'Nenhum Local'), ('Head - Admin', 'Head - Admin'), ('Style - Admin', 'Style - Admin'), ('Script - Admin', 'Script - Admin'), ('Logo - Admin', 'Logo - Admin')], default='Nenhum Local', max_length=100, verbose_name=''),
        ),
    ]



from django.db import models


class ConteudoCustom(models.Model):
    '''
    A classe ConteudoCustom serve para armazernar os(as) Conteúdos customizados do sistema.
    Além de fazer as implementações relacionadas a um único objeto do tipo ConteudoCustom.
    '''
    LOCAL_CHOICES = (
        ('Nenhum Local','Nenhum Local'),
        ('Head - Admin','Head - Admin'),
        ('Style - Admin', 'Style - Admin'),
        ('Script - Admin','Script - Admin'),
        ('Logo - Admin','Logo - Admin'),
    )

    local = models.CharField(
        verbose_name='',
        max_length=100,
        choices=LOCAL_CHOICES,
        default='Nenhum Local',

    )

    conteudo = models.TextField(
        verbose_name="Conteúdo",
        null=True,
        blank=True
    )

    logo = models.FileField(
        verbose_name="Logo",
        upload_to="admin/logo/",
        null=True,
        blank=True

    )

    def __str__(self):
        return self.local

    class Meta:
        app_label = 'django_app_novadata'
        verbose_name = 'Conteúdo Customizado'
        verbose_name_plural = 'Conteúdos Customizados'



from django.contrib import admin

from ..models import ConteudoCustom


@admin.register(ConteudoCustom)
class ConteudoCustomAdmin(admin.ModelAdmin):
    list_display = [
        'id',
        'local',
    ]

    search_fields = [
        'id',
        'local',
    ]

    list_filter = [
        'local',
    ]

    class Media:

        js = (
            'django_app_novadata/js/admin_conteudo_custom.js',  # app static folder
        )


# Generated by Django 3.2.12 on 2022-06-28 19:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_app_novadata', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='conteudocustom',
            name='logo',
            field=models.FileField(null=True, upload_to='admin/logo/', verbose_name='Logo'),
        ),
    ]



from django import template
register = template.Library()
from ..models import ConteudoCustom


@register.simple_tag()
def customizados_style_admin():
    
    customizados = []
    for conteudo in ConteudoCustom.objects.filter(local='Style - Admin'):
        customizados.append(conteudo.conteudo)
    
    return customizados

@register.simple_tag()
def customizados_head_admin():
    
    customizados = []
    for conteudo in ConteudoCustom.objects.filter(local='Head - Admin'):
        customizados.append(conteudo.conteudo)
    
    return customizados

@register.simple_tag()
def customizados_script_admin():
    
    customizados = []
    for conteudo in ConteudoCustom.objects.filter(local='Script - Admin'):
        customizados.append(conteudo.conteudo)
    
    return customizados

@register.simple_tag()
def customizados_logo_admin():

    customizado_logo = ConteudoCustom.objects.filter(local='Logo - Admin').last()
    
    return customizado_logo